@@ -19,8 +19,6 @@ pub trait TDBackgroundFill: Debug + RObject {}
 #[serde(untagged)]
 pub enum BackgroundFill {
   #[doc(hidden)] _Default(()),
-  /// Describes a freeform gradient fill of a background
-  FreeformGradient(BackgroundFillFreeformGradient),
   /// Describes a gradient fill of a background
   Gradient(BackgroundFillGradient),
   /// Describes a solid fill of a background
@@ -37,7 +35,6 @@ impl<'de> Deserialize<'de> for BackgroundFill {
     use serde::de::Error;
     rtd_enum_deserialize!(
       BackgroundFill,
-      (backgroundFillFreeformGradient, FreeformGradient);
       (backgroundFillGradient, Gradient);
       (backgroundFillSolid, Solid);
 
@@ -48,7 +45,6 @@ impl<'de> Deserialize<'de> for BackgroundFill {
 impl RObject for BackgroundFill {
   #[doc(hidden)] fn td_name(&self) -> &'static str {
     match self {
-      BackgroundFill::FreeformGradient(t) => t.td_name(),
       BackgroundFill::Gradient(t) => t.td_name(),
       BackgroundFill::Solid(t) => t.td_name(),
 
@@ -57,7 +53,6 @@ impl RObject for BackgroundFill {
   }
   #[doc(hidden)] fn extra(&self) -> Option<String> {
     match self {
-      BackgroundFill::FreeformGradient(t) => t.extra(),
       BackgroundFill::Gradient(t) => t.extra(),
       BackgroundFill::Solid(t) => t.extra(),
 
@@ -71,22 +66,17 @@ impl BackgroundFill {
   pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
   #[doc(hidden)] pub fn _is_default(&self) -> bool { if let BackgroundFill::_Default(_) = self { true } else { false } }
 
-  pub fn is_freeform_gradient(&self) -> bool { if let BackgroundFill::FreeformGradient(_) = self { true } else { false } }
   pub fn is_gradient(&self) -> bool { if let BackgroundFill::Gradient(_) = self { true } else { false } }
   pub fn is_solid(&self) -> bool { if let BackgroundFill::Solid(_) = self { true } else { false } }
 
-  pub fn on_freeform_gradient<F: FnOnce(&BackgroundFillFreeformGradient)>(&self, fnc: F) -> &Self { if let BackgroundFill::FreeformGradient(t) = self { fnc(t) }; self }
   pub fn on_gradient<F: FnOnce(&BackgroundFillGradient)>(&self, fnc: F) -> &Self { if let BackgroundFill::Gradient(t) = self { fnc(t) }; self }
   pub fn on_solid<F: FnOnce(&BackgroundFillSolid)>(&self, fnc: F) -> &Self { if let BackgroundFill::Solid(t) = self { fnc(t) }; self }
 
-  pub fn as_freeform_gradient(&self) -> Option<&BackgroundFillFreeformGradient> { if let BackgroundFill::FreeformGradient(t) = self { return Some(t) } None }
   pub fn as_gradient(&self) -> Option<&BackgroundFillGradient> { if let BackgroundFill::Gradient(t) = self { return Some(t) } None }
   pub fn as_solid(&self) -> Option<&BackgroundFillSolid> { if let BackgroundFill::Solid(t) = self { return Some(t) } None }
 
 
 
-  pub fn freeform_gradient<T: AsRef<BackgroundFillFreeformGradient>>(t: T) -> Self { BackgroundFill::FreeformGradient(t.as_ref().clone()) }
-
   pub fn gradient<T: AsRef<BackgroundFillGradient>>(t: T) -> Self { BackgroundFill::Gradient(t.as_ref().clone()) }
 
   pub fn solid<T: AsRef<BackgroundFillSolid>>(t: T) -> Self { BackgroundFill::Solid(t.as_ref().clone()) }
@@ -103,74 +93,6 @@ impl AsRef<BackgroundFill> for BackgroundFill {
 
 
 
-/// Describes a freeform gradient fill of a background
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct BackgroundFillFreeformGradient {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// A list of 3 or 4 colors of the freeform gradients in the RGB24 format
-  colors: Vec<i64>,
-  
-}
-
-impl RObject for BackgroundFillFreeformGradient {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "backgroundFillFreeformGradient" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDBackgroundFill for BackgroundFillFreeformGradient {}
-
-
-
-impl BackgroundFillFreeformGradient {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDBackgroundFillFreeformGradientBuilder {
-    let mut inner = BackgroundFillFreeformGradient::default();
-    inner.td_name = "backgroundFillFreeformGradient".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDBackgroundFillFreeformGradientBuilder { inner }
-  }
-
-  pub fn colors(&self) -> &Vec<i64> { &self.colors }
-
-}
-
-#[doc(hidden)]
-pub struct RTDBackgroundFillFreeformGradientBuilder {
-  inner: BackgroundFillFreeformGradient
-}
-
-impl RTDBackgroundFillFreeformGradientBuilder {
-  pub fn build(&self) -> BackgroundFillFreeformGradient { self.inner.clone() }
-
-   
-  pub fn colors(&mut self, colors: Vec<i64>) -> &mut Self {
-    self.inner.colors = colors;
-    self
-  }
-
-}
-
-impl AsRef<BackgroundFillFreeformGradient> for BackgroundFillFreeformGradient {
-  fn as_ref(&self) -> &BackgroundFillFreeformGradient { self }
-}
-
-impl AsRef<BackgroundFillFreeformGradient> for RTDBackgroundFillFreeformGradientBuilder {
-  fn as_ref(&self) -> &BackgroundFillFreeformGradient { &self.inner }
-}
-
-
-
-
-
-
-
 /// Describes a gradient fill of a background
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct BackgroundFillGradient {
@@ -184,7 +106,7 @@ pub struct BackgroundFillGradient {
   top_color: i64,
   /// A bottom color of the background in the RGB24 format
   bottom_color: i64,
-  /// Clockwise rotation angle of the gradient, in degrees; 0-359. Must be always divisible by 45
+  /// Clockwise rotation angle of the gradient, in degrees; 0-359. Should be always divisible by 45
   rotation_angle: i64,
   
 }
