@@ -15,6 +15,8 @@ pub struct BasicGroupFullInfo {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// Chat photo; may be null
+  photo: Option<ChatPhoto>,
   /// Contains full information about a basic group
   description: String,
   /// User identifier of the creator of the group; 0 if unknown
@@ -43,6 +45,8 @@ impl BasicGroupFullInfo {
     RTDBasicGroupFullInfoBuilder { inner }
   }
 
+  pub fn photo(&self) -> &Option<ChatPhoto> { &self.photo }
+
   pub fn description(&self) -> &String { &self.description }
 
   pub fn creator_user_id(&self) -> i64 { self.creator_user_id }
@@ -62,6 +66,12 @@ impl RTDBasicGroupFullInfoBuilder {
   pub fn build(&self) -> BasicGroupFullInfo { self.inner.clone() }
 
    
+  pub fn photo<T: AsRef<ChatPhoto>>(&mut self, photo: T) -> &mut Self {
+    self.inner.photo = Some(photo.as_ref().clone());
+    self
+  }
+
+   
   pub fn description<T: AsRef<str>>(&mut self, description: T) -> &mut Self {
     self.inner.description = description.as_ref().to_string();
     self
