@@ -21,7 +21,7 @@ pub enum ChatActionBar {
   #[doc(hidden)] _Default(()),
   /// The chat is a private or secret chat and the other user can be added to the contact list using the method addContact
   AddContact(ChatActionBarAddContact),
-  /// The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be added to the contact list using the method addContact, or the other user can be blocked using the method blockUser
+  /// The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method blockUser, or the other user can be added to the contact list using the method addContact
   ReportAddBlock(ChatActionBarReportAddBlock),
   /// The chat can be reported as spam using the method reportChat with the reason chatReportReasonSpam
   ReportSpam(ChatActionBarReportSpam),
@@ -181,7 +181,7 @@ impl AsRef<ChatActionBarAddContact> for RTDChatActionBarAddContactBuilder {
 
 
 
-/// The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be added to the contact list using the method addContact, or the other user can be blocked using the method blockUser
+/// The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method blockUser, or the other user can be added to the contact list using the method addContact
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatActionBarReportAddBlock {
   #[doc(hidden)]
@@ -190,6 +190,10 @@ pub struct ChatActionBarReportAddBlock {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings
+  can_unarchive: bool,
+  /// If non-negative, the current user was found by the peer through searchChatsNearby and this is the distance between the users
+  distance: i64,
   
 }
 
@@ -213,6 +217,10 @@ impl ChatActionBarReportAddBlock {
     RTDChatActionBarReportAddBlockBuilder { inner }
   }
 
+  pub fn can_unarchive(&self) -> bool { self.can_unarchive }
+
+  pub fn distance(&self) -> i64 { self.distance }
+
 }
 
 #[doc(hidden)]
@@ -223,6 +231,18 @@ pub struct RTDChatActionBarReportAddBlockBuilder {
 impl RTDChatActionBarReportAddBlockBuilder {
   pub fn build(&self) -> ChatActionBarReportAddBlock { self.inner.clone() }
 
+   
+  pub fn can_unarchive(&mut self, can_unarchive: bool) -> &mut Self {
+    self.inner.can_unarchive = can_unarchive;
+    self
+  }
+
+   
+  pub fn distance(&mut self, distance: i64) -> &mut Self {
+    self.inner.distance = distance;
+    self
+  }
+
 }
 
 impl AsRef<ChatActionBarReportAddBlock> for ChatActionBarReportAddBlock {
@@ -248,6 +268,8 @@ pub struct ChatActionBarReportSpam {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings
+  can_unarchive: bool,
   
 }
 
@@ -271,6 +293,8 @@ impl ChatActionBarReportSpam {
     RTDChatActionBarReportSpamBuilder { inner }
   }
 
+  pub fn can_unarchive(&self) -> bool { self.can_unarchive }
+
 }
 
 #[doc(hidden)]
@@ -281,6 +305,12 @@ pub struct RTDChatActionBarReportSpamBuilder {
 impl RTDChatActionBarReportSpamBuilder {
   pub fn build(&self) -> ChatActionBarReportSpam { self.inner.clone() }
 
+   
+  pub fn can_unarchive(&mut self, can_unarchive: bool) -> &mut Self {
+    self.inner.can_unarchive = can_unarchive;
+    self
+  }
+
 }
 
 impl AsRef<ChatActionBarReportSpam> for ChatActionBarReportSpam {
