@@ -1256,6 +1256,8 @@ pub struct ChatEventMessageUnpinned {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// Unpinned message
+  message: Message,
   
 }
 
@@ -1279,6 +1281,8 @@ impl ChatEventMessageUnpinned {
     RTDChatEventMessageUnpinnedBuilder { inner }
   }
 
+  pub fn message(&self) -> &Message { &self.message }
+
 }
 
 #[doc(hidden)]
@@ -1289,6 +1293,12 @@ pub struct RTDChatEventMessageUnpinnedBuilder {
 impl RTDChatEventMessageUnpinnedBuilder {
   pub fn build(&self) -> ChatEventMessageUnpinned { self.inner.clone() }
 
+   
+  pub fn message<T: AsRef<Message>>(&mut self, message: T) -> &mut Self {
+    self.inner.message = message.as_ref().clone();
+    self
+  }
+
 }
 
 impl AsRef<ChatEventMessageUnpinned> for ChatEventMessageUnpinned {
@@ -1393,9 +1403,9 @@ pub struct ChatEventPhotoChanged {
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
   /// Previous chat photo value; may be null
-  old_photo: Option<Photo>,
+  old_photo: Option<ChatPhoto>,
   /// New chat photo value; may be null
-  new_photo: Option<Photo>,
+  new_photo: Option<ChatPhoto>,
   
 }
 
@@ -1419,9 +1429,9 @@ impl ChatEventPhotoChanged {
     RTDChatEventPhotoChangedBuilder { inner }
   }
 
-  pub fn old_photo(&self) -> &Option<Photo> { &self.old_photo }
+  pub fn old_photo(&self) -> &Option<ChatPhoto> { &self.old_photo }
 
-  pub fn new_photo(&self) -> &Option<Photo> { &self.new_photo }
+  pub fn new_photo(&self) -> &Option<ChatPhoto> { &self.new_photo }
 
 }
 
@@ -1434,13 +1444,13 @@ impl RTDChatEventPhotoChangedBuilder {
   pub fn build(&self) -> ChatEventPhotoChanged { self.inner.clone() }
 
    
-  pub fn old_photo<T: AsRef<Photo>>(&mut self, old_photo: T) -> &mut Self {
+  pub fn old_photo<T: AsRef<ChatPhoto>>(&mut self, old_photo: T) -> &mut Self {
     self.inner.old_photo = Some(old_photo.as_ref().clone());
     self
   }
 
    
-  pub fn new_photo<T: AsRef<Photo>>(&mut self, new_photo: T) -> &mut Self {
+  pub fn new_photo<T: AsRef<ChatPhoto>>(&mut self, new_photo: T) -> &mut Self {
     self.inner.new_photo = Some(new_photo.as_ref().clone());
     self
   }
