@@ -162,6 +162,8 @@ pub struct ChatMemberStatusAdministrator {
   can_pin_messages: bool,
   /// True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them
   can_promote_members: bool,
+  /// True, if the administrator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
+  is_anonymous: bool,
   
 }
 
@@ -205,6 +207,8 @@ impl ChatMemberStatusAdministrator {
 
   pub fn can_promote_members(&self) -> bool { self.can_promote_members }
 
+  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
+
 }
 
 #[doc(hidden)]
@@ -275,6 +279,12 @@ impl RTDChatMemberStatusAdministratorBuilder {
     self
   }
 
+   
+  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
+    self.inner.is_anonymous = is_anonymous;
+    self
+  }
+
 }
 
 impl AsRef<ChatMemberStatusAdministrator> for ChatMemberStatusAdministrator {
@@ -370,6 +380,8 @@ pub struct ChatMemberStatusCreator {
   extra: Option<String>,
   /// A custom title of the owner; 0-16 characters without emojis; applicable to supergroups only
   custom_title: String,
+  /// True, if the creator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
+  is_anonymous: bool,
   /// True, if the user is a member of the chat
   is_member: bool,
   
@@ -397,6 +409,8 @@ impl ChatMemberStatusCreator {
 
   pub fn custom_title(&self) -> &String { &self.custom_title }
 
+  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
+
   pub fn is_member(&self) -> bool { self.is_member }
 
 }
@@ -416,6 +430,12 @@ impl RTDChatMemberStatusCreatorBuilder {
   }
 
    
+  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
+    self.inner.is_anonymous = is_anonymous;
+    self
+  }
+
+   
   pub fn is_member(&mut self, is_member: bool) -> &mut Self {
     self.inner.is_member = is_member;
     self
