@@ -29,6 +29,8 @@ pub enum ChatReportReason {
   Pornography(ChatReportReasonPornography),
   /// The chat contains spam messages
   Spam(ChatReportReasonSpam),
+  /// The location-based chat is unrelated to its stated location
+  UnrelatedLocation(ChatReportReasonUnrelatedLocation),
   /// The chat promotes violence
   Violence(ChatReportReasonViolence),
 
@@ -48,6 +50,7 @@ impl<'de> Deserialize<'de> for ChatReportReason {
       (chatReportReasonCustom, Custom);
       (chatReportReasonPornography, Pornography);
       (chatReportReasonSpam, Spam);
+      (chatReportReasonUnrelatedLocation, UnrelatedLocation);
       (chatReportReasonViolence, Violence);
 
     )(deserializer)
@@ -62,6 +65,7 @@ impl RObject for ChatReportReason {
       ChatReportReason::Custom(t) => t.td_name(),
       ChatReportReason::Pornography(t) => t.td_name(),
       ChatReportReason::Spam(t) => t.td_name(),
+      ChatReportReason::UnrelatedLocation(t) => t.td_name(),
       ChatReportReason::Violence(t) => t.td_name(),
 
       _ => "-1",
@@ -74,6 +78,7 @@ impl RObject for ChatReportReason {
       ChatReportReason::Custom(t) => t.extra(),
       ChatReportReason::Pornography(t) => t.extra(),
       ChatReportReason::Spam(t) => t.extra(),
+      ChatReportReason::UnrelatedLocation(t) => t.extra(),
       ChatReportReason::Violence(t) => t.extra(),
 
       _ => None,
@@ -91,6 +96,7 @@ impl ChatReportReason {
   pub fn is_custom(&self) -> bool { if let ChatReportReason::Custom(_) = self { true } else { false } }
   pub fn is_pornography(&self) -> bool { if let ChatReportReason::Pornography(_) = self { true } else { false } }
   pub fn is_spam(&self) -> bool { if let ChatReportReason::Spam(_) = self { true } else { false } }
+  pub fn is_unrelated_location(&self) -> bool { if let ChatReportReason::UnrelatedLocation(_) = self { true } else { false } }
   pub fn is_violence(&self) -> bool { if let ChatReportReason::Violence(_) = self { true } else { false } }
 
   pub fn on_child_abuse<F: FnOnce(&ChatReportReasonChildAbuse)>(&self, fnc: F) -> &Self { if let ChatReportReason::ChildAbuse(t) = self { fnc(t) }; self }
@@ -98,6 +104,7 @@ impl ChatReportReason {
   pub fn on_custom<F: FnOnce(&ChatReportReasonCustom)>(&self, fnc: F) -> &Self { if let ChatReportReason::Custom(t) = self { fnc(t) }; self }
   pub fn on_pornography<F: FnOnce(&ChatReportReasonPornography)>(&self, fnc: F) -> &Self { if let ChatReportReason::Pornography(t) = self { fnc(t) }; self }
   pub fn on_spam<F: FnOnce(&ChatReportReasonSpam)>(&self, fnc: F) -> &Self { if let ChatReportReason::Spam(t) = self { fnc(t) }; self }
+  pub fn on_unrelated_location<F: FnOnce(&ChatReportReasonUnrelatedLocation)>(&self, fnc: F) -> &Self { if let ChatReportReason::UnrelatedLocation(t) = self { fnc(t) }; self }
   pub fn on_violence<F: FnOnce(&ChatReportReasonViolence)>(&self, fnc: F) -> &Self { if let ChatReportReason::Violence(t) = self { fnc(t) }; self }
 
   pub fn as_child_abuse(&self) -> Option<&ChatReportReasonChildAbuse> { if let ChatReportReason::ChildAbuse(t) = self { return Some(t) } None }
@@ -105,6 +112,7 @@ impl ChatReportReason {
   pub fn as_custom(&self) -> Option<&ChatReportReasonCustom> { if let ChatReportReason::Custom(t) = self { return Some(t) } None }
   pub fn as_pornography(&self) -> Option<&ChatReportReasonPornography> { if let ChatReportReason::Pornography(t) = self { return Some(t) } None }
   pub fn as_spam(&self) -> Option<&ChatReportReasonSpam> { if let ChatReportReason::Spam(t) = self { return Some(t) } None }
+  pub fn as_unrelated_location(&self) -> Option<&ChatReportReasonUnrelatedLocation> { if let ChatReportReason::UnrelatedLocation(t) = self { return Some(t) } None }
   pub fn as_violence(&self) -> Option<&ChatReportReasonViolence> { if let ChatReportReason::Violence(t) = self { return Some(t) } None }
 
 
@@ -119,6 +127,8 @@ impl ChatReportReason {
 
   pub fn spam<T: AsRef<ChatReportReasonSpam>>(t: T) -> Self { ChatReportReason::Spam(t.as_ref().clone()) }
 
+  pub fn unrelated_location<T: AsRef<ChatReportReasonUnrelatedLocation>>(t: T) -> Self { ChatReportReason::UnrelatedLocation(t.as_ref().clone()) }
+
   pub fn violence<T: AsRef<ChatReportReasonViolence>>(t: T) -> Self { ChatReportReason::Violence(t.as_ref().clone()) }
 
 }
@@ -433,6 +443,64 @@ impl AsRef<ChatReportReasonSpam> for RTDChatReportReasonSpamBuilder {
 
 
 
+/// The location-based chat is unrelated to its stated location
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatReportReasonUnrelatedLocation {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  
+}
+
+impl RObject for ChatReportReasonUnrelatedLocation {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatReportReasonUnrelatedLocation" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatReportReason for ChatReportReasonUnrelatedLocation {}
+
+
+
+impl ChatReportReasonUnrelatedLocation {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatReportReasonUnrelatedLocationBuilder {
+    let mut inner = ChatReportReasonUnrelatedLocation::default();
+    inner.td_name = "chatReportReasonUnrelatedLocation".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatReportReasonUnrelatedLocationBuilder { inner }
+  }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatReportReasonUnrelatedLocationBuilder {
+  inner: ChatReportReasonUnrelatedLocation
+}
+
+impl RTDChatReportReasonUnrelatedLocationBuilder {
+  pub fn build(&self) -> ChatReportReasonUnrelatedLocation { self.inner.clone() }
+
+}
+
+impl AsRef<ChatReportReasonUnrelatedLocation> for ChatReportReasonUnrelatedLocation {
+  fn as_ref(&self) -> &ChatReportReasonUnrelatedLocation { self }
+}
+
+impl AsRef<ChatReportReasonUnrelatedLocation> for RTDChatReportReasonUnrelatedLocationBuilder {
+  fn as_ref(&self) -> &ChatReportReasonUnrelatedLocation { &self.inner }
+}
+
+
+
+
+
+
+
 /// The chat promotes violence
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatReportReasonViolence {
