@@ -23,6 +23,8 @@ pub enum KeyboardButtonType {
   RequestLocation(KeyboardButtonTypeRequestLocation),
   /// A button that sends the user's phone number when pressed; available only in private chats
   RequestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber),
+  /// A button that allows the user to create and send a poll when pressed; available only in private chats
+  RequestPoll(KeyboardButtonTypeRequestPoll),
   /// A simple button, with text that should be sent when the button is pressed
   Text(KeyboardButtonTypeText),
 
@@ -39,6 +41,7 @@ impl<'de> Deserialize<'de> for KeyboardButtonType {
       KeyboardButtonType,
       (keyboardButtonTypeRequestLocation, RequestLocation);
       (keyboardButtonTypeRequestPhoneNumber, RequestPhoneNumber);
+      (keyboardButtonTypeRequestPoll, RequestPoll);
       (keyboardButtonTypeText, Text);
 
     )(deserializer)
@@ -50,6 +53,7 @@ impl RObject for KeyboardButtonType {
     match self {
       KeyboardButtonType::RequestLocation(t) => t.td_name(),
       KeyboardButtonType::RequestPhoneNumber(t) => t.td_name(),
+      KeyboardButtonType::RequestPoll(t) => t.td_name(),
       KeyboardButtonType::Text(t) => t.td_name(),
 
       _ => "-1",
@@ -59,6 +63,7 @@ impl RObject for KeyboardButtonType {
     match self {
       KeyboardButtonType::RequestLocation(t) => t.extra(),
       KeyboardButtonType::RequestPhoneNumber(t) => t.extra(),
+      KeyboardButtonType::RequestPoll(t) => t.extra(),
       KeyboardButtonType::Text(t) => t.extra(),
 
       _ => None,
@@ -73,14 +78,17 @@ impl KeyboardButtonType {
 
   pub fn is_request_location(&self) -> bool { if let KeyboardButtonType::RequestLocation(_) = self { true } else { false } }
   pub fn is_request_phone_number(&self) -> bool { if let KeyboardButtonType::RequestPhoneNumber(_) = self { true } else { false } }
+  pub fn is_request_poll(&self) -> bool { if let KeyboardButtonType::RequestPoll(_) = self { true } else { false } }
   pub fn is_text(&self) -> bool { if let KeyboardButtonType::Text(_) = self { true } else { false } }
 
   pub fn on_request_location<F: FnOnce(&KeyboardButtonTypeRequestLocation)>(&self, fnc: F) -> &Self { if let KeyboardButtonType::RequestLocation(t) = self { fnc(t) }; self }
   pub fn on_request_phone_number<F: FnOnce(&KeyboardButtonTypeRequestPhoneNumber)>(&self, fnc: F) -> &Self { if let KeyboardButtonType::RequestPhoneNumber(t) = self { fnc(t) }; self }
+  pub fn on_request_poll<F: FnOnce(&KeyboardButtonTypeRequestPoll)>(&self, fnc: F) -> &Self { if let KeyboardButtonType::RequestPoll(t) = self { fnc(t) }; self }
   pub fn on_text<F: FnOnce(&KeyboardButtonTypeText)>(&self, fnc: F) -> &Self { if let KeyboardButtonType::Text(t) = self { fnc(t) }; self }
 
   pub fn as_request_location(&self) -> Option<&KeyboardButtonTypeRequestLocation> { if let KeyboardButtonType::RequestLocation(t) = self { return Some(t) } None }
   pub fn as_request_phone_number(&self) -> Option<&KeyboardButtonTypeRequestPhoneNumber> { if let KeyboardButtonType::RequestPhoneNumber(t) = self { return Some(t) } None }
+  pub fn as_request_poll(&self) -> Option<&KeyboardButtonTypeRequestPoll> { if let KeyboardButtonType::RequestPoll(t) = self { return Some(t) } None }
   pub fn as_text(&self) -> Option<&KeyboardButtonTypeText> { if let KeyboardButtonType::Text(t) = self { return Some(t) } None }
 
 
@@ -89,6 +97,8 @@ impl KeyboardButtonType {
 
   pub fn request_phone_number<T: AsRef<KeyboardButtonTypeRequestPhoneNumber>>(t: T) -> Self { KeyboardButtonType::RequestPhoneNumber(t.as_ref().clone()) }
 
+  pub fn request_poll<T: AsRef<KeyboardButtonTypeRequestPoll>>(t: T) -> Self { KeyboardButtonType::RequestPoll(t.as_ref().clone()) }
+
   pub fn text<T: AsRef<KeyboardButtonTypeText>>(t: T) -> Self { KeyboardButtonType::Text(t.as_ref().clone()) }
 
 }
@@ -219,6 +229,84 @@ impl AsRef<KeyboardButtonTypeRequestPhoneNumber> for RTDKeyboardButtonTypeReques
 
 
 
+/// A button that allows the user to create and send a poll when pressed; available only in private chats
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct KeyboardButtonTypeRequestPoll {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// If true, only regular polls must be allowed to create
+  force_regular: bool,
+  /// If true, only polls in quiz mode must be allowed to create
+  force_quiz: bool,
+  
+}
+
+impl RObject for KeyboardButtonTypeRequestPoll {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "keyboardButtonTypeRequestPoll" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDKeyboardButtonType for KeyboardButtonTypeRequestPoll {}
+
+
+
+impl KeyboardButtonTypeRequestPoll {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDKeyboardButtonTypeRequestPollBuilder {
+    let mut inner = KeyboardButtonTypeRequestPoll::default();
+    inner.td_name = "keyboardButtonTypeRequestPoll".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDKeyboardButtonTypeRequestPollBuilder { inner }
+  }
+
+  pub fn force_regular(&self) -> bool { self.force_regular }
+
+  pub fn force_quiz(&self) -> bool { self.force_quiz }
+
+}
+
+#[doc(hidden)]
+pub struct RTDKeyboardButtonTypeRequestPollBuilder {
+  inner: KeyboardButtonTypeRequestPoll
+}
+
+impl RTDKeyboardButtonTypeRequestPollBuilder {
+  pub fn build(&self) -> KeyboardButtonTypeRequestPoll { self.inner.clone() }
+
+   
+  pub fn force_regular(&mut self, force_regular: bool) -> &mut Self {
+    self.inner.force_regular = force_regular;
+    self
+  }
+
+   
+  pub fn force_quiz(&mut self, force_quiz: bool) -> &mut Self {
+    self.inner.force_quiz = force_quiz;
+    self
+  }
+
+}
+
+impl AsRef<KeyboardButtonTypeRequestPoll> for KeyboardButtonTypeRequestPoll {
+  fn as_ref(&self) -> &KeyboardButtonTypeRequestPoll { self }
+}
+
+impl AsRef<KeyboardButtonTypeRequestPoll> for RTDKeyboardButtonTypeRequestPollBuilder {
+  fn as_ref(&self) -> &KeyboardButtonTypeRequestPoll { &self.inner }
+}
+
+
+
+
+
+
+
 /// A simple button, with text that should be sent when the button is pressed
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct KeyboardButtonTypeText {
