@@ -12,6 +12,7 @@ pub use self::_common::{
 
 pub use self::account_ttl::*;
 pub use self::address::*;
+pub use self::animated_chat_photo::*;
 pub use self::animation::*;
 pub use self::animations::*;
 pub use self::audio::*;
@@ -24,16 +25,19 @@ pub use self::background::*;
 pub use self::background_fill::*;
 pub use self::background_type::*;
 pub use self::backgrounds::*;
+pub use self::bank_card_action_open_url::*;
+pub use self::bank_card_info::*;
 pub use self::basic_group::*;
 pub use self::basic_group_full_info::*;
 pub use self::bot_command::*;
 pub use self::bot_info::*;
 pub use self::call::*;
-pub use self::call_connection::*;
 pub use self::call_discard_reason::*;
 pub use self::call_id::*;
 pub use self::call_problem::*;
 pub use self::call_protocol::*;
+pub use self::call_server::*;
+pub use self::call_server_type::*;
 pub use self::call_state::*;
 pub use self::callback_query_answer::*;
 pub use self::callback_query_payload::*;
@@ -47,9 +51,12 @@ pub use self::chat_event::*;
 pub use self::chat_event_action::*;
 pub use self::chat_event_log_filters::*;
 pub use self::chat_events::*;
+pub use self::chat_filter::*;
+pub use self::chat_filter_info::*;
 pub use self::chat_invite_link::*;
 pub use self::chat_invite_link_info::*;
 pub use self::chat_list::*;
+pub use self::chat_lists::*;
 pub use self::chat_location::*;
 pub use self::chat_member::*;
 pub use self::chat_member_status::*;
@@ -59,7 +66,16 @@ pub use self::chat_nearby::*;
 pub use self::chat_notification_settings::*;
 pub use self::chat_permissions::*;
 pub use self::chat_photo::*;
+pub use self::chat_photo_info::*;
+pub use self::chat_photos::*;
+pub use self::chat_position::*;
 pub use self::chat_report_reason::*;
+pub use self::chat_source::*;
+pub use self::chat_statistics::*;
+pub use self::chat_statistics_administrator_actions_info::*;
+pub use self::chat_statistics_inviter_info::*;
+pub use self::chat_statistics_message_interaction_info::*;
+pub use self::chat_statistics_message_sender_info::*;
 pub use self::chat_type::*;
 pub use self::chats::*;
 pub use self::chats_nearby::*;
@@ -69,12 +85,16 @@ pub use self::connected_websites::*;
 pub use self::connection_state::*;
 pub use self::contact::*;
 pub use self::count::*;
+pub use self::countries::*;
+pub use self::country_info::*;
 pub use self::custom_request_result::*;
 pub use self::database_statistics::*;
 pub use self::date::*;
+pub use self::date_range::*;
 pub use self::dated_file::*;
 pub use self::deep_link_info::*;
 pub use self::device_token::*;
+pub use self::dice_stickers::*;
 pub use self::document::*;
 pub use self::draft_message::*;
 pub use self::email_address_authentication_code_info::*;
@@ -100,6 +120,7 @@ pub use self::inline_keyboard_button_type::*;
 pub use self::inline_query_result::*;
 pub use self::inline_query_results::*;
 pub use self::input_background::*;
+pub use self::input_chat_photo::*;
 pub use self::input_credentials::*;
 pub use self::input_file::*;
 pub use self::input_identity_document::*;
@@ -132,11 +153,20 @@ pub use self::mask_point::*;
 pub use self::mask_position::*;
 pub use self::message::*;
 pub use self::message_content::*;
+pub use self::message_copy_options::*;
 pub use self::message_forward_info::*;
 pub use self::message_forward_origin::*;
+pub use self::message_interaction_info::*;
+pub use self::message_link::*;
 pub use self::message_link_info::*;
+pub use self::message_reply_info::*;
 pub use self::message_scheduling_state::*;
+pub use self::message_send_options::*;
+pub use self::message_sender::*;
+pub use self::message_senders::*;
 pub use self::message_sending_state::*;
+pub use self::message_statistics::*;
+pub use self::message_thread_info::*;
 pub use self::messages::*;
 pub use self::minithumbnail::*;
 pub use self::network_statistics::*;
@@ -174,6 +204,7 @@ pub use self::payments_provider_stripe::*;
 pub use self::personal_details::*;
 pub use self::personal_document::*;
 pub use self::phone_number_authentication_settings::*;
+pub use self::phone_number_info::*;
 pub use self::photo::*;
 pub use self::photo_size::*;
 pub use self::poll::*;
@@ -184,9 +215,10 @@ pub use self::proxies::*;
 pub use self::proxy::*;
 pub use self::proxy_type::*;
 pub use self::public_chat_type::*;
-pub use self::public_message_link::*;
 pub use self::push_message_content::*;
 pub use self::push_receiver_id::*;
+pub use self::recommended_chat_filter::*;
+pub use self::recommended_chat_filters::*;
 pub use self::recovery_email_address::*;
 pub use self::remote_file::*;
 pub use self::reply_markup::*;
@@ -197,10 +229,11 @@ pub use self::search_messages_filter::*;
 pub use self::seconds::*;
 pub use self::secret_chat::*;
 pub use self::secret_chat_state::*;
-pub use self::send_message_options::*;
 pub use self::session::*;
 pub use self::sessions::*;
 pub use self::shipping_option::*;
+pub use self::statistical_graph::*;
+pub use self::statistical_value::*;
 pub use self::sticker::*;
 pub use self::sticker_set::*;
 pub use self::sticker_set_info::*;
@@ -210,6 +243,7 @@ pub use self::storage_statistics::*;
 pub use self::storage_statistics_by_chat::*;
 pub use self::storage_statistics_by_file_type::*;
 pub use self::storage_statistics_fast::*;
+pub use self::suggested_action::*;
 pub use self::supergroup::*;
 pub use self::supergroup_full_info::*;
 pub use self::supergroup_members_filter::*;
@@ -231,6 +265,8 @@ pub use self::text_entities::*;
 pub use self::text_entity::*;
 pub use self::text_entity_type::*;
 pub use self::text_parse_mode::*;
+pub use self::thumbnail::*;
+pub use self::thumbnail_format::*;
 pub use self::top_chat_category::*;
 pub use self::update::*;
 pub use self::updates::*;
@@ -239,8 +275,6 @@ pub use self::user_full_info::*;
 pub use self::user_privacy_setting::*;
 pub use self::user_privacy_setting_rule::*;
 pub use self::user_privacy_setting_rules::*;
-pub use self::user_profile_photo::*;
-pub use self::user_profile_photos::*;
 pub use self::user_status::*;
 pub use self::user_type::*;
 pub use self::users::*;
@@ -257,6 +291,7 @@ pub use self::web_page_instant_view::*;
 
 mod account_ttl;
 mod address;
+mod animated_chat_photo;
 mod animation;
 mod animations;
 mod audio;
@@ -269,16 +304,19 @@ mod background;
 mod background_fill;
 mod background_type;
 mod backgrounds;
+mod bank_card_action_open_url;
+mod bank_card_info;
 mod basic_group;
 mod basic_group_full_info;
 mod bot_command;
 mod bot_info;
 mod call;
-mod call_connection;
 mod call_discard_reason;
 mod call_id;
 mod call_problem;
 mod call_protocol;
+mod call_server;
+mod call_server_type;
 mod call_state;
 mod callback_query_answer;
 mod callback_query_payload;
@@ -292,9 +330,12 @@ mod chat_event;
 mod chat_event_action;
 mod chat_event_log_filters;
 mod chat_events;
+mod chat_filter;
+mod chat_filter_info;
 mod chat_invite_link;
 mod chat_invite_link_info;
 mod chat_list;
+mod chat_lists;
 mod chat_location;
 mod chat_member;
 mod chat_member_status;
@@ -304,7 +345,16 @@ mod chat_nearby;
 mod chat_notification_settings;
 mod chat_permissions;
 mod chat_photo;
+mod chat_photo_info;
+mod chat_photos;
+mod chat_position;
 mod chat_report_reason;
+mod chat_source;
+mod chat_statistics;
+mod chat_statistics_administrator_actions_info;
+mod chat_statistics_inviter_info;
+mod chat_statistics_message_interaction_info;
+mod chat_statistics_message_sender_info;
 mod chat_type;
 mod chats;
 mod chats_nearby;
@@ -314,12 +364,16 @@ mod connected_websites;
 mod connection_state;
 mod contact;
 mod count;
+mod countries;
+mod country_info;
 mod custom_request_result;
 mod database_statistics;
 mod date;
+mod date_range;
 mod dated_file;
 mod deep_link_info;
 mod device_token;
+mod dice_stickers;
 mod document;
 mod draft_message;
 mod email_address_authentication_code_info;
@@ -345,6 +399,7 @@ mod inline_keyboard_button_type;
 mod inline_query_result;
 mod inline_query_results;
 mod input_background;
+mod input_chat_photo;
 mod input_credentials;
 mod input_file;
 mod input_identity_document;
@@ -377,11 +432,20 @@ mod mask_point;
 mod mask_position;
 mod message;
 mod message_content;
+mod message_copy_options;
 mod message_forward_info;
 mod message_forward_origin;
+mod message_interaction_info;
+mod message_link;
 mod message_link_info;
+mod message_reply_info;
 mod message_scheduling_state;
+mod message_send_options;
+mod message_sender;
+mod message_senders;
 mod message_sending_state;
+mod message_statistics;
+mod message_thread_info;
 mod messages;
 mod minithumbnail;
 mod network_statistics;
@@ -419,6 +483,7 @@ mod payments_provider_stripe;
 mod personal_details;
 mod personal_document;
 mod phone_number_authentication_settings;
+mod phone_number_info;
 mod photo;
 mod photo_size;
 mod poll;
@@ -429,9 +494,10 @@ mod proxies;
 mod proxy;
 mod proxy_type;
 mod public_chat_type;
-mod public_message_link;
 mod push_message_content;
 mod push_receiver_id;
+mod recommended_chat_filter;
+mod recommended_chat_filters;
 mod recovery_email_address;
 mod remote_file;
 mod reply_markup;
@@ -442,10 +508,11 @@ mod search_messages_filter;
 mod seconds;
 mod secret_chat;
 mod secret_chat_state;
-mod send_message_options;
 mod session;
 mod sessions;
 mod shipping_option;
+mod statistical_graph;
+mod statistical_value;
 mod sticker;
 mod sticker_set;
 mod sticker_set_info;
@@ -455,6 +522,7 @@ mod storage_statistics;
 mod storage_statistics_by_chat;
 mod storage_statistics_by_file_type;
 mod storage_statistics_fast;
+mod suggested_action;
 mod supergroup;
 mod supergroup_full_info;
 mod supergroup_members_filter;
@@ -476,6 +544,8 @@ mod text_entities;
 mod text_entity;
 mod text_entity_type;
 mod text_parse_mode;
+mod thumbnail;
+mod thumbnail_format;
 mod top_chat_category;
 mod update;
 mod updates;
@@ -484,8 +554,6 @@ mod user_full_info;
 mod user_privacy_setting;
 mod user_privacy_setting_rule;
 mod user_privacy_setting_rules;
-mod user_profile_photo;
-mod user_profile_photos;
 mod user_status;
 mod user_type;
 mod users;
