@@ -6,7 +6,7 @@ use uuid::Uuid;
 
 
 
-/// Photo description
+/// Describes an image in JPEG format
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct PhotoSize {
   #[doc(hidden)]
@@ -15,14 +15,16 @@ pub struct PhotoSize {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Thumbnail type (see https://core.telegram.org/constructor/photoSize)
+  /// Image type (see https://core.telegram.org/constructor/photoSize)
   #[serde(rename(serialize = "type", deserialize = "type"))] type_: String,
-  /// Information about the photo file
+  /// Information about the image file
   photo: File,
-  /// Photo width
+  /// Image width
   width: i64,
-  /// Photo height
+  /// Image height
   height: i64,
+  /// Sizes of progressive JPEG file prefixes, which can be used to preliminarily show the image
+  progressive_sizes: Vec<i64>,
   
 }
 
@@ -51,6 +53,8 @@ impl PhotoSize {
 
   pub fn height(&self) -> i64 { self.height }
 
+  pub fn progressive_sizes(&self) -> &Vec<i64> { &self.progressive_sizes }
+
 }
 
 #[doc(hidden)]
@@ -85,6 +89,12 @@ impl RTDPhotoSizeBuilder {
     self
   }
 
+   
+  pub fn progressive_sizes(&mut self, progressive_sizes: Vec<i64>) -> &mut Self {
+    self.inner.progressive_sizes = progressive_sizes;
+    self
+  }
+
 }
 
 impl AsRef<PhotoSize> for PhotoSize {
