@@ -21,8 +21,8 @@ pub struct StickerSetInfo {
   title: String,
   /// Name of the sticker set
   name: String,
-  /// Sticker set thumbnail in WEBP format with width and height 100; may be null
-  thumbnail: Option<PhotoSize>,
+  /// Sticker set thumbnail in WEBP or TGS format with width and height 100; may be null
+  thumbnail: Option<Thumbnail>,
   /// True, if the sticker set has been installed by current user
   is_installed: bool,
   /// True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
@@ -37,7 +37,7 @@ pub struct StickerSetInfo {
   is_viewed: bool,
   /// Total number of stickers in the set
   size: i64,
-  /// Contains up to the first 5 stickers from the set, depending on the context. If the client needs more stickers the full set should be requested
+  /// Contains up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full set should be requested
   covers: Vec<Sticker>,
   
 }
@@ -65,7 +65,7 @@ impl StickerSetInfo {
 
   pub fn name(&self) -> &String { &self.name }
 
-  pub fn thumbnail(&self) -> &Option<PhotoSize> { &self.thumbnail }
+  pub fn thumbnail(&self) -> &Option<Thumbnail> { &self.thumbnail }
 
   pub fn is_installed(&self) -> bool { self.is_installed }
 
@@ -112,7 +112,7 @@ impl RTDStickerSetInfoBuilder {
   }
 
    
-  pub fn thumbnail<T: AsRef<PhotoSize>>(&mut self, thumbnail: T) -> &mut Self {
+  pub fn thumbnail<T: AsRef<Thumbnail>>(&mut self, thumbnail: T) -> &mut Self {
     self.inner.thumbnail = Some(thumbnail.as_ref().clone());
     self
   }
