@@ -15,6 +15,8 @@ pub struct SupergroupFullInfo {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// Chat photo; may be null
+  photo: Option<ChatPhoto>,
   /// Contains full information about a supergroup or channel
   description: String,
   /// Number of members in the supergroup or channel; 0 if unknown
@@ -39,8 +41,8 @@ pub struct SupergroupFullInfo {
   can_set_sticker_set: bool,
   /// True, if the supergroup location can be changed
   can_set_location: bool,
-  /// True, if the channel statistics is available through getChatStatisticsUrl
-  can_view_statistics: bool,
+  /// True, if the supergroup or channel statistics are available
+  can_get_statistics: bool,
   /// True, if new chat members will have access to old messages. In public or discussion groups and both public and private channels, old messages are always available, so this option affects only private supergroups without a linked chat. The value of this field is only available for chat administrators
   is_all_history_available: bool,
   /// Identifier of the supergroup sticker set; 0 if none
@@ -73,6 +75,8 @@ impl SupergroupFullInfo {
     RTDSupergroupFullInfoBuilder { inner }
   }
 
+  pub fn photo(&self) -> &Option<ChatPhoto> { &self.photo }
+
   pub fn description(&self) -> &String { &self.description }
 
   pub fn member_count(&self) -> i64 { self.member_count }
@@ -97,7 +101,7 @@ impl SupergroupFullInfo {
 
   pub fn can_set_location(&self) -> bool { self.can_set_location }
 
-  pub fn can_view_statistics(&self) -> bool { self.can_view_statistics }
+  pub fn can_get_statistics(&self) -> bool { self.can_get_statistics }
 
   pub fn is_all_history_available(&self) -> bool { self.is_all_history_available }
 
@@ -122,6 +126,12 @@ impl RTDSupergroupFullInfoBuilder {
   pub fn build(&self) -> SupergroupFullInfo { self.inner.clone() }
 
    
+  pub fn photo<T: AsRef<ChatPhoto>>(&mut self, photo: T) -> &mut Self {
+    self.inner.photo = Some(photo.as_ref().clone());
+    self
+  }
+
+   
   pub fn description<T: AsRef<str>>(&mut self, description: T) -> &mut Self {
     self.inner.description = description.as_ref().to_string();
     self
@@ -194,8 +204,8 @@ impl RTDSupergroupFullInfoBuilder {
   }
 
    
-  pub fn can_view_statistics(&mut self, can_view_statistics: bool) -> &mut Self {
-    self.inner.can_view_statistics = can_view_statistics;
+  pub fn can_get_statistics(&mut self, can_get_statistics: bool) -> &mut Self {
+    self.inner.can_get_statistics = can_get_statistics;
     self
   }
 
